@@ -23,6 +23,8 @@ Configuration parameters:
         (default None)
     format: Display brightness, see placeholders below
         (default '☼: {level}%')
+    hide_when_unavailable: Hide if no backlight is found
+        (default False)
     low_tune_threshold: If current brightness value is below this threshold,
         the value is changed by a minimal value instead of the brightness_delta.
         (default 0)
@@ -44,32 +46,34 @@ from __future__ import division
 
 import os
 
-STRING_NOT_AVAILABLE = 'no available device'
+STRING_NOT_AVAILABLE = "no available device"
 
 
 def get_device():
-    for (path, devices, files) in os.walk('/sys/class/backlight/'):
+    for (path, devices, files) in os.walk("/sys/class/backlight/"):
         for device in devices:
-            if 'brightness' in os.listdir(path + device) and \
-               'max_brightness' in os.listdir(path + device):
+            if "brightness" in os.listdir(
+                path + device
+            ) and "max_brightness" in os.listdir(path + device):
                 return path + device
 
 
 commands = {
-    'xbacklight': {
-        'get': lambda: ['xbacklight', '-get'],
-        'set': lambda level: ['xbacklight', '-time', '0', '-set', str(level)]
+    "xbacklight": {
+        "get": lambda: ["xbacklight", "-get"],
+        "set": lambda level: ["xbacklight", "-time", "0", "-set", str(level)],
+    },
+    "light": {
+        "get": lambda: ["light", "-G"],
+        "set": lambda level: ["light", "-S", str(level)],
     },
-    'light': {
-        'get': lambda: ['light', '-G'],
-        'set': lambda level: ['light', '-S', str(level)]
-    }
 }
 
 
 class Py3status:
     """
     """
+
     # available configuration parameters
     brightness_delta = 8
     brightness_initial = None
@@ -77,33 +81,35 @@ class Py3status:
     button_down = 5
     button_up = 4
     cache_timeout = 10
-    command = 'xbacklight'
+    command = "xbacklight"
     device = None
-    format = u'☼: {level}%'
+    format = u"☼: {level}%"
+    hide_when_unavailable = False
     low_tune_threshold = 0
 
     class Meta:
         deprecated = {
-            'rename': [
+            "rename": [
                 {
-                    'param': 'device_path',
-                    'new': 'device',
-                    'msg': 'obsolete parameter use `device`',
-                },
-            ],
+                    "param": "device_path",
+                    "new": "device",
+                    "msg": "obsolete parameter use `device`",
+                }
+            ]
         }
 
     def post_config_hook(self):
         if not self.device:
             self.device = get_device()
-        elif '/' not in self.device:
+        elif "/" not in self.device:
             self.device = "/sys/class/backlight/%s" % self.device
         if self.device is None:
-            raise Exception(STRING_NOT_AVAILABLE)
+            if self.hide_when_unavailable:
+                return
+            else:
+                raise Exception(STRING_NOT_AVAILABLE)
 
-        self.format = self.py3.update_placeholder_formats(
-            self.format, {'level': ':d'}
-        )
+        self.format = self.py3.update_placeholder_formats(self.format, {"level": ":d"})
         # check for an error code and an output
         self.command_available = False
         try:
@@ -112,8 +118,8 @@ class Py3status:
                 float(output)
                 self.command_available = True
             except ValueError:
-                self.command_available = False
-        except:
+                pass
+        except self.py3.CommandError:
             pass
 
         if self.command_available and self.brightness_initial:
@@ -124,7 +130,7 @@ class Py3status:
             return None
 
         level = self._get_backlight_level()
-        button = event['button']
+        button = event["button"]
         if button == self.button_up:
             delta = self.brightness_delta if level >= self.low_tune_threshold else 1
             level += delta
@@ -144,29 +150,29 @@ class Py3status:
     def _get_backlight_level(self):
         if self.command_available:
             return float(self.py3.command_output(self._command_get()))
-        for brightness_line in open("%s/brightness" % self.device, 'rb'):
+        for brightness_line in open("%s/brightness" % self.device, "rb"):
             brightness = int(brightness_line)
-        for brightness_max_line in open("%s/max_brightness" % self.device, 'rb'):
+        for brightness_max_line in open("%s/max_brightness" % self.device, "rb"):
             brightness_max = int(brightness_max_line)
         return brightness * 100 / brightness_max
 
     # Returns the string array for the command to get the current backlight level
     def _command_get(self):
-        return commands[self.command]['get']()
+        return commands[self.command]["get"]()
 
     # Returns the string array for the command to set the current backlight level
     def _command_set(self, level):
-        return commands[self.command]['set'](level)
+        return commands[self.command]["set"](level)
 
     def backlight(self):
         full_text = ""
         if self.device is not None:
             level = self._get_backlight_level()
-            full_text = self.py3.safe_format(self.format, {'level': level})
+            full_text = self.py3.safe_format(self.format, {"level": level})
 
         response = {
-            'cached_until': self.py3.time_in(self.cache_timeout),
-            'full_text': full_text
+            "cached_until": self.py3.time_in(self.cache_timeout),
+            "full_text": full_text,
         }
         return response
 
@@ -176,4 +182,5 @@ if __name__ == "__main__":
     Run module in test mode.
     """
     from py3status.module_test import module_test
+
     module_test(Py3status)
