@@ -18,7 +18,8 @@ Configuration parameters:
         (default False)
     thresholds: thresholds to use for color changes
         *(default {'free': [(0, 'bad'), (10, 'degraded'), (100, 'good')],
-        'total': [(0, "good"), (1024, 'degraded'), (1024 * 1024, 'bad')]})*
+        'total': [(0, 'good'), (1024, 'degraded'), (1024 * 1024, 'bad')],
+        'used_percent': [(0, 'good'), (40, 'degraded'), (75, 'bad')]})*
     unit: unit to use. If the unit contains a multiplier prefix, only this
         exact unit will ever be used
         (default "B/s")
@@ -42,7 +43,8 @@ format_space placeholders:
 
 Color thresholds:
     {free} Change color based on the value of free
-    {used} Change color based on the value of used_percent
+    {used} Change color based on the value of used
+    {used_percent} Change color based on the value of used_percent
     {read} Change color based on the value of read
     {total} Change color based on the value of total
     {write} Change color based on the value of write
@@ -73,6 +75,7 @@ class Py3status:
     thresholds = {
         "free": [(0, "bad"), (10, "degraded"), (100, "good")],
         "total": [(0, "good"), (1024, "degraded"), (1024 * 1024, "bad")],
+        "used_percent": [(0, "good"), (40, "degraded"), (75, "bad")],
     }
     unit = "B/s"
 
@@ -84,36 +87,31 @@ class Py3status:
             value - value (float)
             unit - unit (string)
         """
-        self.last_interface = None
-        self.last_stat = self._get_io_stats(self.disk)
+        self.last_diskstats = self._get_diskstats(self.disk)
         self.last_time = time()
 
-    def space_and_io(self):
+        self.thresholds_init = self.py3.get_color_names_list(self.format)
+
+    def diskdata(self):
         self.values = {"disk": self.disk if self.disk else "all"}
+        threshold_data = {}
 
         if self.py3.format_contains(self.format, ["read", "write", "total"]):
-            # time from previous check
-            ios = self._get_io_stats(self.disk)
-            timedelta = time() - self.last_time
-
-            read = ios[0] - self.last_stat[0]
-            write = ios[1] - self.last_stat[1]
-
-            # update last_ info
-            self.last_stat = self._get_io_stats(self.disk)
-            self.last_time = time()
-
-            read /= timedelta
-            write /= timedelta
+            diskstats = self._get_diskstats(self.disk)
+            current_time = time()
 
+            timedelta = current_time - self.last_time
+            read = (diskstats[0] - self.last_diskstats[0]) / timedelta
+            write = (diskstats[1] - self.last_diskstats[1]) / timedelta
             total = read + write
 
+            self.last_diskstats = diskstats
+            self.last_time = current_time
+
             self.values["read"] = self._format_rate(read)
             self.values["total"] = self._format_rate(total)
             self.values["write"] = self._format_rate(write)
-            self.py3.threshold_get_color(read, "read")
-            self.py3.threshold_get_color(total, "total")
-            self.py3.threshold_get_color(write, "write")
+            threshold_data.update({"read": read, "write": write, "total": total})
 
         if self.py3.format_contains(self.format, ["free", "used*", "total_space"]):
             free, used, used_percent, total_space = self._get_free_space(self.disk)
@@ -130,8 +128,13 @@ class Py3status:
             self.values["total_space"] = self.py3.safe_format(
                 self.format_space, {"value": total_space}
             )
-            self.py3.threshold_get_color(free, "free")
-            self.py3.threshold_get_color(used, "used")
+            threshold_data.update(
+                {"free": free, "used": used, "used_percent": used_percent}
+            )
+
+        for x in self.thresholds_init:
+            if x in threshold_data:
+                self.py3.threshold_get_color(threshold_data[x], x)
 
         return {
             "cached_until": self.py3.time_in(self.cache_timeout),
@@ -167,7 +170,7 @@ class Py3status:
 
         return free, used, 100 * used / total, total
 
-    def _get_io_stats(self, disk):
+    def _get_diskstats(self, disk):
         if disk and disk.startswith("/dev/"):
             disk = disk[5:]
         read = 0
