@@ -4,6 +4,8 @@ Display system RAM, SWAP and CPU utilization.
 
 Configuration parameters:
     cache_timeout: how often we refresh this module in seconds (default 10)
+    cpu_freq_unit: the unit of CPU frequency to use in report, case insensitive.
+        ['kHz', 'MHz', 'GHz'] (default 'GHz')
     format: output format string
         *(default '[\?color=cpu CPU: {cpu_used_percent}%], '
         '[\?color=mem Mem: {mem_used}/{mem_total} {mem_unit} ({mem_used_percent}%)]')*
@@ -15,10 +17,14 @@ Configuration parameters:
         (default '°C')
     thresholds: thresholds to use for color changes
         (default [(0, "good"), (40, "degraded"), (75, "bad")])
-    zone: thermal zone to use. If None try to guess CPU temperature
+    zone: Either a path in sysfs to CPU temperature sensor, or an lm_sensors thermal zone to use.
+        If None try to guess CPU temperature
         (default None)
 
 Format placeholders:
+    {cpu_freq_avg} average CPU frequency across all cores
+    {cpu_freq_max} highest CPU clock frequency
+    {cpu_freq_unit} unit for frequency
     {cpu_temp} cpu temperature
     {cpu_used_percent} cpu used percentage
     {load1} load average over the last minute
@@ -46,7 +52,7 @@ Color thresholds:
 NOTE: If using the `{cpu_temp}` option, the `sensors` command should
 be available, provided by the `lm-sensors` or `lm_sensors` package.
 
-@author Shahin Azad <ishahinism at Gmail>, shrimpza, guiniol
+@author Shahin Azad <ishahinism at Gmail>, shrimpza, guiniol, JackDoan <me at jackdoan dot com>
 
 SAMPLE OUTPUT
 [
@@ -68,6 +74,7 @@ class Py3status:
 
     # available configuration parameters
     cache_timeout = 10
+    cpu_freq_unit = "GHz"
     format = (
         "[\?color=cpu CPU: {cpu_used_percent}%], "
         "[\?color=mem Mem: {mem_used}/{mem_total} {mem_unit} ({mem_used_percent}%)]"
@@ -96,6 +103,8 @@ class Py3status:
                 padding=padding, precision=precision
             )
             return {
+                "cpu_freq_avg": format_vals,
+                "cpu_freq_max": format_vals,
                 "cpu_usage": format_vals,
                 "cpu_used_percent": format_vals,
                 "cpu_temp": format_vals,
@@ -143,6 +152,8 @@ class Py3status:
             "update_placeholder_format": [
                 {
                     "placeholder_formats": {
+                        "cpu_freq_avg": ":.2f",
+                        "cpu_freq_max": ":.2f",
                         "cpu_usage": ":.2f",
                         "cpu_used_percent": ":.2f",
                         "cpu_temp": ":.2f",
@@ -172,14 +183,53 @@ class Py3status:
             temp_unit = "unknown unit"
         self.temp_unit = temp_unit
         self.init = {"meminfo": []}
-        names = ["cpu_temp", "cpu_percent", "load", "mem", "swap"]
-        placeholders = ["cpu_temp", "cpu_used_percent", "load*", "mem_*", "swap_*"]
+        names = [
+            "cpu_freq_avg",
+            "cpu_freq_max",
+            "cpu_temp",
+            "cpu_percent",
+            "load",
+            "mem",
+            "swap",
+        ]
+        placeholders = [
+            "cpu_freq_avg",
+            "cpu_freq_max",
+            "cpu_temp",
+            "cpu_used_percent",
+            "load*",
+            "mem_*",
+            "swap_*",
+        ]
         for name, placeholder in zip(names, placeholders):
             self.init[name] = self.py3.format_contains(self.format, placeholder)
             if name in ["mem", "swap"] and self.init[name]:
                 self.init["meminfo"].append(name)
 
-    def _get_stat(self):
+    @staticmethod
+    def _get_cpu_freqs():
+        freqs = []
+        with open("/proc/cpuinfo") as f:
+            for line in f:
+                if "cpu MHz" in line:
+                    freq = float(line.split(":")[-1])
+                    freqs.append(freq)
+        return freqs
+
+    def _calc_cpu_freqs(self, unit):
+        cpu_freqs = self._get_cpu_freqs()
+
+        freq_avg = sum(cpu_freqs) / len(cpu_freqs)
+        freq_max = max(cpu_freqs)
+
+        # multiply both by 1e6 to convert to Hz to pass to format_units
+        (freq_max, _) = self.py3.format_units(freq_max * 1e6, unit=unit, si=True)
+        (freq_avg, _) = self.py3.format_units(freq_avg * 1e6, unit=unit, si=True)
+
+        return {"avg": freq_avg, "max": freq_max}
+
+    @staticmethod
+    def _get_stat():
         # kernel/system statistics. man -P 'less +//proc/stat' procfs
         with open("/proc/stat") as f:
             fields = f.readline().split()
@@ -243,7 +293,7 @@ class Py3status:
         self.last_cpu.update(cpu)
         return cpu_used_percent
 
-    def _get_cputemp(self, zone, unit):
+    def _get_cputemp_with_lmsensors(self, zone=None):
         """
         Tries to determine CPU temperature using the 'sensors' command.
         Searches for the CPU temperature by looking for a value prefixed
@@ -253,10 +303,6 @@ class Py3status:
 
         sensors = None
         command = ["sensors"]
-        if unit == u"°F":
-            command.append("-f")
-        elif unit not in [u"°C", "K"]:
-            return "unknown unit"
         if zone:
             try:
                 sensors = self.py3.command_output(command + [zone])
@@ -267,16 +313,47 @@ class Py3status:
         m = re.search("(Core 0|CPU Temp).+\+(.+).+\(.+", sensors)
         if m:
             cpu_temp = float(m.groups()[1].strip()[:-2])
-            if unit == "K":
-                cpu_temp += 273.15
         else:
             cpu_temp = "?"
 
         return cpu_temp
 
+    def _get_cputemp(self, zone, unit):
+        if zone is not None:
+            try:
+                with open(zone) as f:
+                    cpu_temp = f.readline()
+                    cpu_temp = float(cpu_temp) / 1000  # convert from mdegC to degC
+            except (OSError, IOError, ValueError):
+                # FileNotFoundError does not exist on Python < 3.3, so we catch OSError instead
+                # ValueError can be thrown if zone was a file that didn't have a float
+                # if zone was not a file, it might be a sensor!
+                cpu_temp = self._get_cputemp_with_lmsensors(zone=zone)
+
+        else:
+            cpu_temp = self._get_cputemp_with_lmsensors()
+
+        if cpu_temp is float:
+            if unit == u"°F":
+                cpu_temp = cpu_temp * (9.0 / 5.0) + 32
+            elif unit == "K":
+                cpu_temp += 273.15
+
+        return cpu_temp
+
     def sysdata(self):
         sys = {"max_used_percent": 0, "temp_unit": self.temp_unit}
 
+        if self.init["cpu_freq_max"] or self.init["cpu_freq_avg"]:
+            cpu_freqs = self._calc_cpu_freqs(self.cpu_freq_unit)
+            if self.init["cpu_freq_max"]:
+                sys["cpu_freq_max"] = cpu_freqs["max"]
+                self.py3.threshold_get_color(sys["cpu_freq_max"], "cpu_freq")
+
+            if self.init["cpu_freq_avg"]:
+                sys["cpu_freq_avg"] = cpu_freqs["avg"]
+                self.py3.threshold_get_color(sys["cpu_freq_avg"], "cpu_freq")
+
         if self.init["cpu_percent"]:
             sys["cpu_used_percent"] = self._calc_cpu_percent(self._get_stat())
             self.py3.threshold_get_color(sys["cpu_used_percent"], "cpu")
