@@ -18,7 +18,7 @@ from py3status.constants import COLOR_NAMES
 from py3status.formatter import Formatter, Composite
 from py3status.request import HttpResponse
 from py3status.storage import Storage
-from py3status.util import Gradiants
+from py3status.util import Gradients
 from py3status.version import version
 
 
@@ -93,7 +93,7 @@ class Py3:
 
     # Shared by all Py3 Instances
     _formatter = None
-    _gradients = Gradiants()
+    _gradients = Gradients()
     _none_color = NoneColor()
     _storage = Storage()
 
@@ -632,9 +632,14 @@ class Py3:
         # Unless the requested update is in less than a second
         if sync_to is None:
             if seconds and seconds < 1:
-                sync_to = 0
+                if 1 % seconds == 0:
+                    sync_to = seconds
+                else:
+                    sync_to = 0
             else:
                 sync_to = 1
+                if seconds:
+                    seconds -= 0.1
 
         requested = time() + seconds - offset
 
@@ -698,6 +703,8 @@ class Py3:
 
         :param format_strings: Accepts a format string or a list of format strings.
         """
+        if not format_strings:
+            return []
         if not getattr(self._py3status_module, "thresholds", None):
             return []
         if isinstance(format_strings, basestring):
@@ -1197,7 +1204,7 @@ class Py3:
                         else:
                             break
             except TypeError:
-                pass
+                color = None
 
         # save color so it can be accessed via safe_format()
         if name:
@@ -1249,6 +1256,9 @@ class Py3:
         if headers is None:
             headers = {}
 
+        if timeout is None:
+            timeout = getattr(self._py3status_module, "request_timeout", 10)
+
         if "User-Agent" not in headers:
             headers["User-Agent"] = "py3status/{} {}".format(version, self._uid)
 
